# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-01 01:23
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0047_auto_20180813_1214'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserLiveComment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comment', models.TextField(verbose_name='\u8bc4\u8bba')),
                ('submit_date', models.DateTimeField(db_index=True, default=django.utils.timezone.now, verbose_name='\u63d0\u4ea4\u65e5\u671f')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='\u4f5c\u8005')),
                ('user_live', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserLive')),
            ],
        ),
    ]
