# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-11 08:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0034_auto_20180521_1400'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='sectionattach',
            table='bee_django_course_section_attach',
        ),
        migrations.AlterModelTable(
            name='sectionvideo',
            table='bee_django_course_section_video',
        ),
        migrations.AlterModelTable(
            name='userassignment',
            table='bee_django_course_user_assignment',
        ),
        migrations.AlterModelTable(
            name='userassignmentimage',
            table='bee_django_course_user_assignment_image',
        ),
        migrations.AlterModelTable(
            name='usercourse',
            table='bee_django_course_user_course',
        ),
        migrations.AlterModelTable(
            name='usercoursesection',
            table='bee_django_course_user_course_section',
        ),
        migrations.AlterModelTable(
            name='userimage',
            table='bee_django_course_user_image',
        ),
    ]
