# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-13 04:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0046_section_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userlive',
            name='call_count',
            field=models.IntegerField(default=1),
        ),
    ]
