<style>
    .nav {
        background-color: #4B6788;
        height: 40px;
        color: #ffffff;
        line-height: 40px;
        padding: 0 10px;
    }

    .nav a {
        color: #ffffff;
    }
</style>

<div class="nav">
    <a href="/">首页 |</a>
    <a href="{% url 'bee_django_course:users' %}">用户课程设置 |</a>
    {% if perms.bee_django_course.view_all_courses %}
        <a href="{% url 'bee_django_course:course_list' %}">课程管理</a> |
    {% endif %}
    {% if perms.bee_django_course.view_all_sections %}
        <a href="{% url 'bee_django_course:section_list' %}">课件管理</a> |
    {% endif %}
    {% if perms.bee_django_course.view_all_sections %}
        <a href="{% url 'bee_django_course:video_list' %}">视频管理</a> |
    {% endif %}
    <a href="{% url 'bee_django_course:manage_user_assignments' %}">作业管理</a> |
    <a href="{% url 'bee_django_course:live_list' %}">录播管理</a> |


</div>
{% load bootstrap3 %}
{% bootstrap_messages %}