# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-17 11:37
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0032_auto_20180517_1848'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='course',
            options={'ordering': ['-id'], 'permissions': (('can_manage_course', '\u53ef\u4ee5\u8fdb\u5165\u8bfe\u7a0b\u7ba1\u7406\u9875'), ('view_all_courses', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u8bfe\u7a0b'), ('can_choose_course', 'can choose course')), 'verbose_name': 'course\u8bfe\u7a0b'},
        ),
        migrations.AlterModelOptions(
            name='section',
            options={'ordering': ['-id'], 'permissions': (('view_all_sections', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u8bfe\u4ef6'),), 'verbose_name': 'course\u8bfe\u4ef6'},
        ),
        migrations.AlterModelOptions(
            name='usercoursesection',
            options={'ordering': ['-created_at'], 'permissions': [('view_all_usercoursesection', '\u67e5\u770b\u6240\u6709\u5b66\u751f\u8bfe\u4ef6'), ('view_teach_usercoursessection', '\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u8bfe\u4ef6')], 'verbose_name': 'course\u5b66\u751f\u8bfe\u4ef6'},
        ),
        migrations.AlterModelOptions(
            name='userlive',
            options={'ordering': ['-created_at'], 'permissions': (('view_all_userlives', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u5b66\u751f\u7684\u5f55\u64ad'), ('view_teach_userlives', '\u53ef\u4ee5\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u7684\u5f55\u64ad')), 'verbose_name': 'course\u5b66\u751f\u5f55\u64ad'},
        ),
        migrations.AlterModelOptions(
            name='video',
            options={'ordering': ['-created_at'], 'permissions': (('view_all_videos', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u89c6\u9891'),), 'verbose_name': 'course\u89c6\u9891'},
        ),
    ]
