# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-07 07:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0050_sectionquestion_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='sectionquestion',
            name='tip_correct',
            field=models.TextField(null=True, verbose_name='\u6b63\u786e\u65f6\u63d0\u793a\u8bcd'),
        ),
        migrations.AddField(
            model_name='sectionquestion',
            name='tip_wrong',
            field=models.TextField(null=True, verbose_name='\u9519\u8bef\u65f6\u63d0\u793a\u8bcd'),
        ),
    ]
