# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-12-18 08:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Course',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u8bfe\u7a0b\u540d\u5b57')),
                ('subtitle', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u8bfe\u7a0b\u526f\u6807\u9898')),
                ('level', models.IntegerField(blank=True, default=0, verbose_name='\u8bfe\u7a0b\u7684level')),
                ('is_del', models.IntegerField(default=0)),
                ('type_int', models.IntegerField(verbose_name='\u8bfe\u7a0b\u7c7b\u578b')),
            ],
            options={
                'db_table': 'bee_django_course_course',
            },
        ),
    ]
