<style>
    .logo {
        background-color: #4B6788;
        height: 60px;
        color: #ffffff;
        font-size: 30px;
        padding: 10px;
    }
</style>
<div class="logo">课程管理系统
    <span style="font-size: 14px;"> v 0.0.94</span>
</div>
