# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-04-11 05:43
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0025_userlive'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='userlive',
            table='bee_django_course_user_live',
        ),
    ]
