{% extends "bee_django_course/base.html" %}
{% load comments %}
{% load bee_django_course_filter %}
{% block content %}
    <h4>录制视频详情</h4>
    <div class="video">
        <iframe src="{{ record_video_id | get_video_src }}" frameborder="0" width="100%" height="100%"></iframe>
    </div>

    {% get_comment_form for user_live as form %}
    <form action="{% comment_form_target  %}" method="post">
        {% csrf_token %}
        {% for field in form %}
            {{ field }}
        {% endfor %}
    </form>
{% endblock %}