# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-11 02:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0053_section_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='question_passed_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u95ee\u7b54\u901a\u8fc7\u65f6\u95f4'),
        ),
    ]
