# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-04 07:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0048_userlivecomment'),
    ]

    operations = [
        migrations.CreateModel(
            name='SectionQuestion',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('question', models.CharField(max_length=180, verbose_name='\u95ee\u9898')),
                ('question_type', models.IntegerField(choices=[(1, '\u5355\u9009'), (2, '\u591a\u9009')], default=1, verbose_name='\u95ee\u9898\u7c7b\u578b')),
                ('order_by', models.IntegerField(default=0, verbose_name='\u987a\u5e8f')),
                ('section', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Section', verbose_name='\u5173\u8054\u7684\u8bfe\u4ef6')),
            ],
            options={
                'ordering': ['order_by'],
                'db_table': 'bee_django_course_section_question',
            },
        ),
        migrations.CreateModel(
            name='SectionQuestionOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('option', models.CharField(max_length=180, verbose_name='\u9009\u9879')),
                ('order_by', models.IntegerField(default=0, verbose_name='\u987a\u5e8f')),
                ('is_correct', models.BooleanField(default=False, verbose_name='\u662f\u5426\u6b63\u786e\u7b54\u6848')),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.SectionQuestion', verbose_name='\u95ee\u9898')),
            ],
            options={
                'ordering': ['order_by'],
                'db_table': 'bee_django_course_section_question_option',
            },
        ),
    ]
